==> mathjax-docs_2.7+20171212.orig.tar.gz: mathjax-docs-2.7+20171212/README.md <==
# MathJax Documentation

[![Documentation Status](https://readthedocs.org/projects/mathjax/badge/?version=latest)](https://docs.mathjax.org)


## Beautiful math in all browsers.

MathJax is an open-source JavaScript display engine for LaTeX, MathML, and
AsciiMath notation that works in all modern browsers.  It was designed with
the goal of consolidating the recent advances in web technologies into a
single, definitive, math-on-the-web platform supporting the major browsers
and operating systems.  It requires no setup on the part of the user (no
plugins to download or software to install), so the page author can write
web documents that include mathematics and be confident that users will be
able to view it naturally and easily.  Simply include MathJax and some
mathematics in a web page, and MathJax does the rest.

See <http://www.mathjax.org/> or <https://github.com/mathjax/MathJax/> for additional details.


## Beautiful documentation.

The MathJax installation and usage documentation is available in this repository. The documents are also
available on the MathJax web site on line at <http://docs.mathjax.org>.  Please help us improve the documentation!
You can use the editor feature on github to to simplify this.

## Community

The main MathJax website is <http://www.mathjax.org>, and it includes
announcements and other important information.  MathJax is maintained and
distributed on GitHub at <http://github.com/mathjax/MathJax>.  A user forum
for asking questions and getting assistance is hosted at Google, and the
bug tracker is hosted at GitHub:

Bug tracker:         <https://github.com/mathjax/MathJax/issues>  
MathJax-Users Group: <http://groups.google.com/group/mathjax-users>

Before reporting a bug, please check that it has not already been reported.
Also, please use the bug tracker for reporting bugs rather than the help forum.


## License

Just like MathJax, this documentation is license under Apache License, Version 2.0.

> Copyright (c) 2009-2013 The MathJax Consortium
>
> Licensed under the Apache License, Version 2.0 (the "License");
> you may not use this file except in compliance with the License.
> You may obtain a copy of the License at
>
>  http://www.apache.org/licenses/LICENSE-2.0
>
> Unless required by applicable law or agreed to in writing, software
> distributed under the License is distributed on an "AS IS" BASIS,
> WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
> See the License for the specific language governing permissions and
> limitations under the License.

==> mathjax-docs_3.2+20240903.orig.tar.gz: mathjax-docs-3.2+20240903/README.md <==
# MathJax Documentation

[![Documentation Status](https://readthedocs.org/projects/mathjax/badge/?version=latest)](https://docs.mathjax.org)


## Beautiful and accessible math in all browsers.

MathJax is an open-source JavaScript display engine for LaTeX, MathML, and
AsciiMath notation that works in all modern browsers, as well as server-side in node applications.  It was designed with
the goal of consolidating the recent advances in web technologies into a
single, definitive, math-on-the-web platform supporting the major browsers
and operating systems.  It requires no setup on the part of the user (no
plugins to download or software to install), so the page author can write
web documents that include mathematics and be confident that users will be
able to view it naturally and easily.  Simply include MathJax and some
mathematics in a web page, and MathJax does the rest.

See <http://www.mathjax.org/> or <https://github.com/mathjax/MathJax/> for additional details.


## Beautiful documentation.

The MathJax installation and usage documentation is available in this repository. The documents are also
available on the MathJax web site online at <http://docs.mathjax.org>.  Please help us improve the documentation!
You can use the editor feature on github to simplify this.

## Community

The main MathJax website is <https://www.mathjax.org>, and it includes
announcements and other important information.  MathJax is maintained and
distributed on GitHub at <https://github.com/mathjax/MathJax>, and the source code is housed at <https://github.com/mathjax/MathJax-src>.  A user forum
for asking questions and getting assistance is hosted at Google, and the
bug tracker is hosted at GitHub:

Bug tracker:         <https://github.com/mathjax/MathJax/issues>  
MathJax-Users Group: <https://groups.google.com/group/mathjax-users>

Before reporting a bug, please check that it has not already been reported.
Please use the bug tracker for reporting bugs rather than the help forum, and use the forum rather than the bug tracker for asking usage questions.


## License

Just like MathJax, this documentation is license under Apache License, Version 2.0.

> Copyright (c) 2009-2020 The MathJax Consortium
>
> Licensed under the Apache License, Version 2.0 (the "License");
> you may not use this file except in compliance with the License.
> You may obtain a copy of the License at
>
>  http://www.apache.org/licenses/LICENSE-2.0
>
> Unless required by applicable law or agreed to in writing, software
> distributed under the License is distributed on an "AS IS" BASIS,
> WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
> See the License for the specific language governing permissions and
> limitations under the License.
